@@ -11,7 +11,8 @@ from matplotlib.lines import Line2D
 from matplotlib.patches import *
 from .base import *
 from .logic import *
-from .storage import *
+from .logic.bitwise import *
+from .logic.storage import *
 from .schematic_symbols import *
 
 gridsize = 5
@@ -140,9 +141,9 @@ class Schematic:
         self.sinks = []     # a list of net sinks with tuples   [symbol, x, y, wire]
         
         self.mapping = {}
-        self.mapping[And] = AndSymbol
+        self.mapping[And2] = AndSymbol
         self.mapping[Not] = NotSymbol
-        self.mapping[Or] = OrSymbol
+        self.mapping[Or2] = OrSymbol
         
         self.mapping[Add] = AddSymbol
         self.mapping[Sub] = SubSymbol
@@ -847,7 +848,8 @@ class Schematic:
             if (source['wire'] == sinkWire):
                 return source
             
-        raise Exception('No source to wire "{}" in {}'.format(sinkWire.name, self.sources) )
+        sourceNames = [x['wire'].getFullPath() for x in self.sources]
+        raise Exception('No source to wire "{}" in {}'.format(sinkWire.getFullPath(), sourceNames ) )
             
     def findSinkTuples(self, sourceWire):
         ret = []
